<?php

/*
 * copyright (c) 2010 MDBitz - Matthew John Denton - mdbitz.com
 *
 * This file is part of WordPress Amazon Associate Plugin.
 *
 * WordPress Amazon Associate is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * WordPress Amazon Associate is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with WordPress Amazon Associate.
 * If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * Amazon Product
 *
 * This file contains the class AmazonProduct
 *
 * @author Matthew John Denton <matt@mdbitz.com>
 * @package com.mdbitz.wordpress.amazon_associate
 */

/**
 * AmazonProduct is a utility class to easily ouput Amazon Products
 *
 * @package com.mdbitz.wordpress.amazon_associate
 */
class AmazonProduct {

    /**
     * Ouput Amazon Product Link
     * 
     * @global WPAA $wpaa
     *
     * @param string $content Link Text
     * @param string $id Product Id
     * @param string $locale Locale
     * @param string $type Id Type
     * @param string $target link target
     */
    public static function link($content, $id, $locale = null, $type = "ASIN",
            $target = "_blank", $rel = "nofollow", $container = null,
            $container_class = null, $title = null ) {
        global $wpaa;
        $output_str = $content;
        if (!is_null($id)) {
            $result = $wpaa->getCacheHandler()->getProduct( $id, $locale, $type );
            if ($result->isSuccess() && isset($result->Items[0])) {
                $output_str = '<a href="' . urldecode($result->Items[0]->DetailPageURL) . '" target="' . $target . '" rel="' . $rel . '" title="' . (is_null($title) ? '' : $title) . '" >' . $content . '</a>';
            }
        }
        if( ! empty($container) ) {
            if( ! empty($container_class) ) {
                $output_str = '<' . $container . ' class="' . $container_class . '" >' . $output_str . '</' . $container . '>';
            } else {
                $output_str = '<' . $container . ' >' . $output_str . '</' . $container . '>';
            }
        }
        return $output_str;
    }

    /**
     * Ouput Amazon Product Image
     *
     * @global WPAA $wpaa
     *
     * @param string $content Link Text
     * @param string $id Product Id
     * @param string $size Image Size
     * @param boolean $link Should Image be a Link
     * @param locale $locale Locale
     * @param string $type Id Type
     * @param string $target link target
     */
    public static function image($content, $id, $size="medium", $link = false,
            $locale = null, $type = "ASIN", $target = "_blank",
            $rel = "nofollow", $class = null, $container = null,
            $container_class = null, $alt = null, $title = null ) {
        global $wpaa;
        $output_str = $content;
        if (!is_null($id)) {
            $response_group = AmazonProduct_ResponseGroup::ITEM_ATTRIBUTES .", " . AmazonProduct_ResponseGroup::IMAGES;
            $result = $wpaa->getCacheHandler()->getProduct( $id, $locale, $type, $response_group );
            if ($result->isSuccess() && isset($result->Items[0])) {
                $size = strtolower($size);
                $image = null;
                switch ($size) {
                    case "small":
                        $image = $result->Items[0]->SmallImage;
                        break;
                    case "large":
                        $image = $result->Items[0]->LargeImage;
                        break;
                    default :
                        $image = $result->Items[0]->MediumImage;
                        break;
                }
                if( ! is_null($class) ) {
                    $image->set( "class", $class );
                }
                if( ! is_null($rel) ) {
                    $image->set( "rel", $rel );
                }
                if( ! is_null($title) ) {
                    $image->set("title", $title );
                } else {
                    $image->set("title", $content );
                }
                if( ! is_null($alt) ) {
                    $image->set("alt", $alt );
                }
                $output_str = '';
                if ($link) {
                    $output_str = '<a href="' . urldecode($result->Items[0]->DetailPageURL) . '" target="' . $target . '">';
                }
                if (!is_null($image)) {
                    $output_str .= $image->toHTML();
                } else {
                    $output_str .= $content;
                }
                if ($link) {
                    $output_str .= '</a>';
                }
            }
        }
        if( ! empty($container) ) {
            if( ! empty($container_class) ) {
                $output_str = '<' . $container . ' class="' . $container_class . '" >' . $output_str . '</' . $container . '>';
            } else {
                $output_str = '<' . $container . ' >' . $output_str . '</' . $container . '>';
            }
        }
        return $output_str;
    }
    
    /**
     * Ouput Amazon Product Enhanced Link
     * 
     * @global WPAA $wpaa
     *
     * @param string $id Product Id
     * @param string $locale Locale
     */
    public static function enhanced($asin, $locale = null, $new_window = true,
            $show_border = true, $larger_image = true, $price = "All", 
            $background_color = "FFFFFF", $text_color="000000", $link_color="0000FF" ) {
        global $wpaa;
        $outputStr = '<iframe src="';
        // get Locale
        $locale = $wpaa->getGeoLocale( $locale );
        // Append service url
        $outputStr .= self::getURL( $locale ) . '?';
        // Append Link Target
        if( $new_window === true ) {
            $outputStr .= 'lt1=_blank&';
        } else {
            $outputStr .= 'lt1=_top&';
        }
        // Append Show Border
        if( $show_border === true ) {
            $outputStr .= 'bc1=000000&';
        } else {
            $outputStr .= 'bc1=FFFFFF&';
        }
        // Append Image Size
        if( $larger_image === true ) {
            $outputStr .= 'IS2=1&';
        } else {
            $outputStr .= 'IS1=1&';
        }
        // Append Pricing Options
        if( $price == "New" ) {
            $outputStr .= 'nou=1&';
        } else if ( $price == "Hide" ) {
            $outputStr .= 'npa=1&';
        }
        // Append Style Options
        $outputStr .= 'bg1=' . $background_color . '&';
        $outputStr .= 'fc1=' . $text_color . '&';
        $outputStr .= 'lc1=' . $link_color . '&';
        // Append Associate Tag
        global $post;
        $author_id = null;
        if( !is_null( $post ) && isset( $post->post_author ) ) {
            $author_id = $post->post_author;
        }
        $outputStr .= 't=' . $wpaa->getAssociateId( $locale, $author_id ) . '&';
        // Append Miscellaneous
        $outputStr .= 'o=' . $wpaa->locale_o[ $locale ] . '&';
        $outputStr .= 'p=8&l=as1&m=amazon&f=ifr&';
        // Append ASIN ID
        $outputStr .= 'asins=' . $asin;
        // Close IFrame
        $outputStr .= '" style="width:120px;height:240px;" scrolling="no" marginwidth="0" marginheight="0" frameborder="0"></iframe>';
        return $outputStr;
    }

    /**
     * get the service URL for desired locale
     *
     * @param string $locale
     * @return string
     */
    public static function getURL( $locale ) {
        switch( $locale ) {
            case "UK":
                return "http://rcm-uk.amazon.co.uk/e/cm";
                break;
            case "CA":
                return "http://rcm-ca.amazon.ca/e/cm";
                break;
            case "CN":
                return "http://rcm-cn.amazon.cn/e/cm";
                break;
            case "DE":
                return "http://rcm-de.amazon.de/e/cm";
                break;
            case "FR":
                return "http://rcm-fr.amazon.fr/e/cm";
                break;
            case "JP":
                return "http://rcm-jp.amazon.co.jp/e/cm";
                break;
            case "IT":
                return "http://rcm-it.amazon.it/e/cm";
                break;
            default:
                return "http://rcm.amazon.com/e/cm";
                break;
        }
    }
    
}