<?php
/*
 * copyright (c) 2010 MDBitz - Matthew John Denton - mdbitz.com
 *
 * This file is part of WordPress Amazon Associate Plugin.
 *
 * WordPress Amazon Associate is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * WordPress Amazon Associate is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with WordPress Amazon Associate.
 * If not, see <http://www.gnu.org/licenses/>.
*/

/**
 * WPAA_ShortCodeHandler
 *
 * This file contains the class WPAA_ShortCodeHandler
 *
 * @author Matthew John Denton <matt@mdbitz.com>
 * @package com.mdbitz.wordpress.amazon_associate
 */

/**
 * Short Code Handler Class for WordPress Amazon Associate plugin
 *
 * @package com.mdbitz.wordpress.amazon_associate
 */
class WPAA_ShortCodeHandler {

    /**
     * Constructor
     */
    function __construct( $mappings = null) {
        add_shortcode('amazon_link', array(&$this,'amazonLinkHandler'));
        add_shortcode('amazon_image', array(&$this,'amazonImageHandler'));
        add_shortcode('amazon_enhanced', array(&$this,'amazonEnhancedHandler'));
        add_shortcode('amazon_carousel', array(&$this,'amazonCarouselHandler'));
        add_shortcode('amazon_mp3_clips', array(&$this,'amazonMP3ClipsHandler'));
        add_shortcode('amazon_my_favorites', array(&$this,'amazonMyFavoritesHandler'));
        add_shortcode('amazon_search', array(&$this,'amazonSearchHandler'));
        add_shortcode('amazon_omakase', array(&$this,'amazonOmakaseHandler'));
        add_shortcode('amazon_product_cloud', array(&$this,'amazonProductCloudHandler'));
        if( $mappings != null ) {
            foreach( $mappings as $mapping) {
                foreach( $mapping as $name => $function ) {
                    add_shortcode( $name, array(&$this,$function));
                }
            }
        }
    }

    /**
     * Amazon Link Short Code Handler
     * @param array $atts
     * @param string $content
     * @param string $code
     */
    public function amazonLinkHandler( $atts, $content=null, $code="" ) {
        global $wpaa;
        $atts = shortcode_atts( array( 'id'=>null, 'locale'=> null,
            'type' => 'ASIN', 'target' => '_blank', 'rel' => "nofollow",
            'container' => null, 'container_class' => null, 'title' => null ), $atts );
        return AmazonProduct::link($content, $atts['id'], $atts['locale'],
            $atts['type'], $atts['target'], $atts['rel'], $atts['container'],
            $atts['container_class'], $atts['title'] );
    }

    /**
     * Amazon Image Short Code Handler
     * @param array $atts
     * @param string $content
     * @param string $code
     */
    public function amazonImageHandler( $atts, $content=null, $code="" ) {
        global $wpaa;
        $atts = shortcode_atts( array( 'id'=>null, 'locale'=>null,
            'size'=>'medium', 'type' => 'ASIN', 'link' => false,
            'target' => '_blank', 'rel' => "nofollow", 'class'=> null,
            'container'=>null, 'container_class' => null, 'alt' => null,
            'title' => null ), $atts );
        return AmazonProduct::image($content, $atts['id'], $atts['size'],
                $atts['link'], $atts['locale'], $atts['type'], $atts['target'],
                $atts['rel'], $atts['class'], $atts['container'],
                $atts['container_class'], $atts['alt'], $atts['title']);
    }

    /**
     * Amazon Enhanced Link Short Code Handler
     * @param array $atts
     * @param string $content
     * @param string $code
     */
    public function amazonEnhancedHandler( $atts, $content=null, $code="" ) {
        global $wpaa;
        $atts = shortcode_atts( array('asin' => null, 'locale' => null, 'new_window' => true,
            'show_border' => true, 'larger_image' => true, 'price' => "All",
            'background_color' => "FFFFFF", 'text_color' => "000000",
            'link_color' => "0000FF" ), $atts );
        return AmazonProduct::enhanced($atts['asin'], $atts['locale'],
               $atts['new_window'], $atts['show_border'], $atts['larger_image'],
               $atts['price'], $atts['background_color'], $atts['text_color'],
               $atts['link_color'] );
    }

    /**
     * Amazon Carousel Short Code Handler
     * @param array $atts
     * @param string $content
     * @param string $code
     */
    public function amazonCarouselHandler( $atts, $content=null, $code="" ) {
        $widget = new AmazonWidget_Carousel( $this->mergeWidgetOptions( AmazonWidget_Carousel::getDefaultShortCodeOptions(), $atts ) );
        return $widget->toHTML();
    }

    /**
     * Amazon MP3 Clips Short Code Handler
     * @param array $atts
     * @param string $content
     * @param string $code
     */
    public function amazonMP3ClipsHandler( $atts, $content=null, $code="" ) {
        $widget = new AmazonWidget_MP3Clips( $this->mergeWidgetOptions( AmazonWidget_MP3Clips::getDefaultShortCodeOptions(), $atts ) );
        return $widget->toHTML();
    }

    /**
     * Amazon My Favorites Short Code Handler
     * @param array $atts
     * @param string $content
     * @param string $code
     */
    public function amazonMyFavoritesHandler( $atts, $content=null, $code="" ) {
        $widget = new AmazonWidget_MyFavorites( $this->mergeWidgetOptions( AmazonWidget_MyFavorites::getDefaultShortCodeOptions(), $atts ) );
        return $widget->toHTML();
    }

    /**
     * Amazon Search Short Code Handler
     * @param array $atts
     * @param string $content
     * @param string $code
     */
    public function amazonSearchHandler( $atts, $content=null, $code="" ) {
        $widget = new AmazonWidget_Search( $this->mergeWidgetOptions( AmazonWidget_Search::getDefaultShortCodeOptions(), $atts ) );
        return $widget->toHTML();
    }

    /**
     * Amazon Omakase Short Code Handler
     * @param array $atts
     * @param string $content
     * @param string $code
     */
    public function amazonOmakaseHandler( $atts, $content=null, $code="" ) {
        $widget = new AmazonWidget_Omakase( $this->mergeWidgetOptions( AmazonWidget_Omakase::getDefaultShortCodeOptions(), $atts ) );
        return $widget->toHTML();
    }

    /**
     * Amazon ProductCloud Short Code Handler
     * @param array $atts
     * @param string $content
     * @param string $code
     */
    public function amazonProductCloudHandler( $atts, $content=null, $code="" ) {
        $widget = new AmazonWidget_ProductCloud( $this->mergeWidgetOptions( AmazonWidget_ProductCloud::getDefaultShortCodeOptions(), $atts ) );
        return $widget->toHTML();
    }

    /**
     * Merge Widget Options and include plugin compliance settings
     * @param Array $defaultArgs
     * @param Array $atts
     * @return Array
     */
    private function mergeWidgetOptions( $defaultArgs, $atts ) {
        if( isset( $atts['marketplace'] ) ) {
            $atts['market_place'] = $atts['marketplace'];
            unset( $atts['marketplace'] );
        }
        return shortcode_atts( $defaultArgs, $atts );
    }

}